document.addEventListener('DOMContentLoaded', function() {
    // Reproductor de audio
    const audio = new Audio('musica/fondo.mp3');
    const playButton = document.getElementById('playButton');
    const playIcon = document.getElementById('playIcon');
    const progressBar = document.getElementById('progressBar');
    const progressContainer = document.getElementById('progressContainer');
    let isPlaying = false;

    playButton.addEventListener('click', function() {
        if (isPlaying) {
            audio.pause();
            playIcon.className = 'fas fa-play';
        } else {
            audio.play();
            playIcon.className = 'fas fa-pause';
        }
        isPlaying = !isPlaying;
    });

    audio.addEventListener('timeupdate', function() {
        const progress = (audio.currentTime / audio.duration) * 100;
        progressBar.style.width = `${progress}%`;
    });

    progressContainer.addEventListener('click', function(e) {
        const clickPosition = e.offsetX / this.offsetWidth;
        audio.currentTime = clickPosition * audio.duration;
    });

    audio.addEventListener('ended', function() {
        playIcon.className = 'fas fa-play';
        isPlaying = false;
        progressBar.style.width = '0%';
    });

    // Cuenta regresiva
    function updateCountdown() {
        const weddingDate = new Date('January 28, 2025 00:00:00').getTime();
        
        function update() {
            const now = new Date().getTime();
            const distance = weddingDate - now;

            const days = Math.floor(distance / (1000 * 60 * 60 * 24));
            const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
            const seconds = Math.floor((distance % (1000 * 60)) / 1000);

            document.getElementById('days').textContent = days.toString().padStart(2, '0');
            document.getElementById('hours').textContent = hours.toString().padStart(2, '0');
            document.getElementById('minutes').textContent = minutes.toString().padStart(2, '0');
            document.getElementById('seconds').textContent = seconds.toString().padStart(2, '0');

            if (distance < 0) {
                clearInterval(interval);
                document.querySelector('.countdown').innerHTML = '<h3>¡El día ha llegado!</h3>';
            }
        }

        update();
        const interval = setInterval(update, 1000);
    }

    // Iniciar cuenta regresiva
    updateCountdown();

    // Carrusel
    function initializeCarousel() {
        const track = document.getElementById('carouselTrack');
        const slides = Array.from(track.getElementsByClassName('carousel-slide'));
        const prevButton = document.getElementById('prevButton');
        const nextButton = document.getElementById('nextButton');

        // Clonar slides para efecto infinito
        function cloneSlides() {
            const slidesToClone = slides.length * 2; // Clonar dos veces para asegurar suficientes slides
            for (let i = 0; i < slidesToClone; i++) {
                const clone = slides[i % slides.length].cloneNode(true);
                track.appendChild(clone);
            }
            return Array.from(track.getElementsByClassName('carousel-slide'));
        }

        const allSlides = cloneSlides();
        let currentIndex = slides.length; // Comenzar en el conjunto original
        let isTransitioning = false;

        function updateSlides(smooth = true) {
            if (smooth) {
                track.style.transition = 'transform 0.5s ease-in-out';
            } else {
                track.style.transition = 'none';
            }

            const slideWidth = allSlides[0].offsetWidth;
            const gap = 30; // Debe coincidir con el gap en CSS
            const translateX = -(currentIndex * (slideWidth + gap));
            track.style.transform = `translateX(${translateX}px)`;

            // Actualizar clases active
            allSlides.forEach((slide, index) => {
                slide.classList.remove('active');
                if (index === currentIndex) {
                    slide.classList.add('active');
                }
            });
        }

        function resetPositionIfNeeded() {
            if (currentIndex >= allSlides.length - slides.length) {
                currentIndex = slides.length;
                updateSlides(false);
            } else if (currentIndex < slides.length) {
                currentIndex = allSlides.length - slides.length * 2;
                updateSlides(false);
            }
        }

        function handleTransitionEnd() {
            if (isTransitioning) {
                isTransitioning = false;
                resetPositionIfNeeded();
            }
        }

        function nextSlide() {
            if (!isTransitioning) {
                isTransitioning = true;
                currentIndex++;
                updateSlides(true);
            }
        }

        function prevSlide() {
            if (!isTransitioning) {
                isTransitioning = true;
                currentIndex--;
                updateSlides(true);
            }
        }

        // Event Listeners para el carrusel
        prevButton.addEventListener('click', prevSlide);
        nextButton.addEventListener('click', nextSlide);
        track.addEventListener('transitionend', handleTransitionEnd);

        // Touch events para el carrusel
        let touchStartX = 0;
        let touchEndX = 0;

        track.addEventListener('touchstart', e => {
            touchStartX = e.changedTouches[0].screenX;
        });

        track.addEventListener('touchend', e => {
            touchEndX = e.changedTouches[0].screenX;
            if (touchStartX - touchEndX > 50) {
                nextSlide();
            } else if (touchEndX - touchStartX > 50) {
                prevSlide();
            }
        });

        // Inicializar el carrusel
        window.addEventListener('resize', () => {
            updateSlides(false);
        });

        updateSlides(false);
    }

    // Inicializar carrusel
    initializeCarousel();

    // Intersection Observer para la animación del título
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.classList.add('visible');
                observer.unobserve(entry.target);
            }
        });
    }, {
        threshold: 0.1
    });

    const title = document.querySelector('.title');
    if (title) {
        observer.observe(title);
    }


     // Soporte táctil para la tarjeta de regalo
    const giftCard = document.querySelector('.gift-card');
    
    if (giftCard) {
        giftCard.addEventListener('touchstart', function() {
            this.classList.toggle('touch-active');
        });
    }

    function handleSubmit(event) {
        event.preventDefault();
        
        // Obtener los valores del formulario
        const nombre = document.getElementById('nombre').value;
        const asistencia = document.getElementById('asistencia').value;
        const mensaje = document.getElementById('mensaje').value;
        
        // Construir el mensaje para WhatsApp
        let text = `¡Hola! Soy ${nombre} y ${asistencia} a la boda.\n`;
        if (mensaje) {
            text += `\nMensaje: ${mensaje}`;
        }
        
        // Codificar el mensaje para la URL
        const encodedText = encodeURIComponent(text);
        
        // Construir la URL de WhatsApp
        const whatsappUrl = `https://wa.me/51947365823?text=${encodedText}`;
        
        // Abrir WhatsApp en una nueva ventana
        window.open(whatsappUrl, '_blank');
    }
});